import greenfoot.*;

/**
 * CLASS: Scroll (subclass of Object)<br>
 * AUTHOR: danpost (greenfoot.org username)<br>
 * DATE: May 4, 2015
 * <br>
 * DESCRIPTION: a support superclass for an infinite scrolling world;<br>
 * capable of horizontal, vertical or universal scrolling;<br>
 * only actors are scrolled;
 */
public class Scroll
{
    private World scrollWorld; // the world whose actors are to be scrolled

    public Scroll(World world)
    {
        scrollWorld = world;
    }
    
    /**
     * scrolls all movable actors using given change amounts;
     * 
     * @param dx change in scrolled amount along x-axis
     * @paramdy change in scrolled amount along y-axis
     */
    public void scroll(int dx, int dy)
    {
        // get vector values (for QActor type objects)
        int qd = (int)(Math.hypot(dy, dx)*QActor.QVAL);
        int qa = (int)((Math.atan2(dy, dx)*180/Math.PI)*QActor.QVAL);
        // scroll actors
        for (Object obj : scrollWorld.getObjects(null))
        {
            // see if actor is of QActor type
            if (obj instanceof QActor)
            {
                // scroll QActor object
                ((QActor)obj).move(-qd, qa);
            }
            else
            {
                // scroll non-QActor object
                Actor actor = (Actor)obj;
                actor.setLocation(actor.getX()-dx, actor.getY()-dy);
            }
        }
    }
}